pub struct CanonicalComposition { /* private fields */ }Expand description
The raw canonical composition operation.
Callers should generally use ComposingNormalizer instead of this API.
However, this API is provided for callers such as HarfBuzz that specifically
want access to the raw canonical composition operation e.g. for use in a
glyph-availability-guided custom normalizer.
Implementations
Sourceimpl CanonicalComposition
impl CanonicalComposition
Sourcepub fn as_borrowed(&self) -> CanonicalCompositionBorrowed<'_>
pub fn as_borrowed(&self) -> CanonicalCompositionBorrowed<'_>
Constructs a borrowed version of this type for more efficient querying.
Sourcepub const fn new() -> CanonicalCompositionBorrowed<'static>
pub const fn new() -> CanonicalCompositionBorrowed<'static>
Constructs a new CanonicalCompositionBorrowed using compiled data.
✨ Enabled with the compiled_data Cargo feature.
Sourcepub fn try_new_with_buffer_provider(
provider: &(impl BufferProvider + ?Sized),
) -> Result<Self, DataError>
pub fn try_new_with_buffer_provider( provider: &(impl BufferProvider + ?Sized), ) -> Result<Self, DataError>
A version of [Self :: new] that uses custom data provided by a BufferProvider.
✨ Enabled with the serde Cargo feature.
Sourcepub fn try_new_unstable<D>(provider: &D) -> Result<Self, DataError>
pub fn try_new_unstable<D>(provider: &D) -> Result<Self, DataError>
A version of Self::new that uses custom data provided by a DataProvider.