Struct Baked

struct Baked

Baked data

🚧 This code is considered unstable; it may change at any time, in breaking or non-breaking ways, including in SemVer minor releases. In particular, the `DataProvider` implementations are only guaranteed to match with this version's `*_unstable` providers. Use with caution.

Implementations

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<NormalizerNfkdTablesV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<NormalizerNfdTablesV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<NormalizerNfdSupplementV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<NormalizerNfdDataV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<NormalizerNfcV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<NormalizerUts46DataV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<NormalizerNfkdDataV1>, DataError>

impl Debug for Baked

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for Baked

impl RefUnwindSafe for Baked

impl Send for Baked

impl Sync for Baked

impl Unpin for Baked

impl UnsafeUnpin for Baked

impl UnwindSafe for Baked

impl<T> Any for Baked

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Baked

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Baked

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> ErasedDestructor for Baked

impl<T> From for Baked

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Baked

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Baked

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Baked

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<Y> DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<NeverMarker<Y>>, DataError>