Struct DecompositionData

struct DecompositionData<'data> { ... }

Decomposition data

🚧 This code is considered unstable; it may change at any time, in breaking or non-breaking ways, including in SemVer minor releases. While the serde representation of data structs is guaranteed to be stable, their Rust representation might not be. Use with caution.

Fields

trie: CodePointTrie<'data, u32>

Trie for decomposition.

passthrough_cap: u16

The passthrough bounds of NFD/NFC are lowered to this maximum instead. (16-bit, because cannot be higher than 0x0300, which is the bound for NFC.)

Implementations

impl MaybeAsVarULE for DecompositionData<'_>

impl<'a> Yokeable for DecompositionData<'static>

fn transform(self: &'a Self) -> &'a <Self as >::Output
fn transform_owned(self: Self) -> <Self as >::Output
unsafe fn make(this: <Self as >::Output) -> Self
fn transform_mut<F>(self: &'a mut Self, f: F)
where
    F: 'static + for<'b> FnOnce(&'b mut <Self as >::Output)

impl<'data> Clone for DecompositionData<'data>

fn clone(self: &Self) -> DecompositionData<'data>

impl<'data> Debug for DecompositionData<'data>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'data> Freeze for DecompositionData<'data>

impl<'data> PartialEq for DecompositionData<'data>

fn eq(self: &Self, other: &DecompositionData<'data>) -> bool

impl<'data> RefUnwindSafe for DecompositionData<'data>

impl<'data> Send for DecompositionData<'data>

impl<'data> StructuralPartialEq for DecompositionData<'data>

impl<'data> Sync for DecompositionData<'data>

impl<'data> Unpin for DecompositionData<'data>

impl<'data> UnsafeUnpin for DecompositionData<'data>

impl<'data> UnwindSafe for DecompositionData<'data>

impl<'zf, 'zf_inner> ZeroFrom for DecompositionData<'zf>

fn zero_from(this: &'zf DecompositionData<'zf_inner>) -> Self

impl<T> Any for DecompositionData<'data>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DecompositionData<'data>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DecompositionData<'data>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DecompositionData<'data>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> ErasedDestructor for DecompositionData<'data>

impl<T> From for DecompositionData<'data>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DecompositionData<'data>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for DecompositionData<'data>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DecompositionData<'data>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DecompositionData<'data>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>