Struct NonRecursiveDecompositionSupplement

struct NonRecursiveDecompositionSupplement<'data> { ... }

Non-recursive canonical decompositions that differ from DecompositionData.

🚧 This code is considered unstable; it may change at any time, in breaking or non-breaking ways, including in SemVer minor releases. While the serde representation of data structs is guaranteed to be stable, their Rust representation might not be. Use with caution.

Fields

trie: CodePointTrie<'data, u32>

Trie for the supplementary non-recursive decompositions

scalars24: ZeroVec<'data, char>

Decompositions with at least one character outside the BMP

Implementations

impl MaybeAsVarULE for NonRecursiveDecompositionSupplement<'_>

impl<'a> Yokeable for NonRecursiveDecompositionSupplement<'static>

fn transform(self: &'a Self) -> &'a <Self as >::Output
fn transform_owned(self: Self) -> <Self as >::Output
unsafe fn make(this: <Self as >::Output) -> Self
fn transform_mut<F>(self: &'a mut Self, f: F)
where
    F: 'static + for<'b> FnOnce(&'b mut <Self as >::Output)

impl<'data> Clone for NonRecursiveDecompositionSupplement<'data>

fn clone(self: &Self) -> NonRecursiveDecompositionSupplement<'data>

impl<'data> Debug for NonRecursiveDecompositionSupplement<'data>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'data> Freeze for NonRecursiveDecompositionSupplement<'data>

impl<'data> PartialEq for NonRecursiveDecompositionSupplement<'data>

fn eq(self: &Self, other: &NonRecursiveDecompositionSupplement<'data>) -> bool

impl<'data> RefUnwindSafe for NonRecursiveDecompositionSupplement<'data>

impl<'data> Send for NonRecursiveDecompositionSupplement<'data>

impl<'data> StructuralPartialEq for NonRecursiveDecompositionSupplement<'data>

impl<'data> Sync for NonRecursiveDecompositionSupplement<'data>

impl<'data> Unpin for NonRecursiveDecompositionSupplement<'data>

impl<'data> UnsafeUnpin for NonRecursiveDecompositionSupplement<'data>

impl<'data> UnwindSafe for NonRecursiveDecompositionSupplement<'data>

impl<'zf, 'zf_inner> ZeroFrom for NonRecursiveDecompositionSupplement<'zf>

fn zero_from(this: &'zf NonRecursiveDecompositionSupplement<'zf_inner>) -> Self

impl<T> Any for NonRecursiveDecompositionSupplement<'data>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for NonRecursiveDecompositionSupplement<'data>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for NonRecursiveDecompositionSupplement<'data>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for NonRecursiveDecompositionSupplement<'data>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> ErasedDestructor for NonRecursiveDecompositionSupplement<'data>

impl<T> From for NonRecursiveDecompositionSupplement<'data>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for NonRecursiveDecompositionSupplement<'data>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for NonRecursiveDecompositionSupplement<'data>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for NonRecursiveDecompositionSupplement<'data>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for NonRecursiveDecompositionSupplement<'data>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>