Struct Composition

struct Composition<'data, I> { ... }
where
    I: Iterator<Item = char>

An iterator adaptor that turns an Iterator over char into a lazily-decomposed and then canonically composed char sequence.

Implementations

impl<'data, I> Composition<'data, I>

fn compose(self: &Self, starter: char, second: char) -> Option<char>

Performs canonical composition (including Hangul) on a pair of characters or returns None if these characters don't compose. Composition exclusions are taken into account.

impl<'data, I> Debug for Composition<'data, I>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'data, I> Freeze for Composition<'data, I>

impl<'data, I> RefUnwindSafe for Composition<'data, I>

impl<'data, I> Send for Composition<'data, I>

impl<'data, I> Sync for Composition<'data, I>

impl<'data, I> Unpin for Composition<'data, I>

impl<'data, I> UnsafeUnpin for Composition<'data, I>

impl<'data, I> UnwindSafe for Composition<'data, I>

impl<I> IntoIterator for Composition<'data, I>

fn into_iter(self: Self) -> I

impl<I> Iterator for Composition<'_, I>

fn next(self: &mut Self) -> Option<char>

impl<T> Any for Composition<'data, I>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Composition<'data, I>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Composition<'data, I>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> ErasedDestructor for Composition<'data, I>

impl<T> From for Composition<'data, I>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Composition<'data, I>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Composition<'data, I>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Composition<'data, I>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>