Struct DecomposingNormalizer
struct DecomposingNormalizer { ... }
A normalizer for performing decomposing normalization.
Implementations
impl DecomposingNormalizer
fn as_borrowed(self: &Self) -> DecomposingNormalizerBorrowed<'_>Constructs a borrowed version of this type for more efficient querying.
const fn new_nfd() -> DecomposingNormalizerBorrowed<'static>NFD constructor using compiled data.
✨ Enabled with the
compiled_dataCargo feature.fn try_new_nfd_unstable<D>(provider: &D) -> Result<Self, DataError> where D: DataProvider<NormalizerNfdDataV1> + DataProvider<NormalizerNfdTablesV1> + ?SizedA version of
Self::new_nfdthat uses custom data provided by aDataProvider.⚠️ The bounds on provider may change over time, including in SemVer minor releases.const fn new_nfkd() -> DecomposingNormalizerBorrowed<'static>NFKD constructor using compiled data.
✨ Enabled with the
compiled_dataCargo feature.fn try_new_nfkd_unstable<D>(provider: &D) -> Result<Self, DataError> where D: DataProvider<NormalizerNfkdDataV1> + DataProvider<NormalizerNfdTablesV1> + DataProvider<NormalizerNfkdTablesV1> + ?SizedA version of
Self::new_nfkdthat uses custom data provided by aDataProvider.⚠️ The bounds on provider may change over time, including in SemVer minor releases.
impl Debug for DecomposingNormalizer
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for DecomposingNormalizer
impl RefUnwindSafe for DecomposingNormalizer
impl Send for DecomposingNormalizer
impl Sync for DecomposingNormalizer
impl Unpin for DecomposingNormalizer
impl UnsafeUnpin for DecomposingNormalizer
impl UnwindSafe for DecomposingNormalizer
impl<T> Any for DecomposingNormalizer
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for DecomposingNormalizer
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for DecomposingNormalizer
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> ErasedDestructor for DecomposingNormalizer
impl<T> From for DecomposingNormalizer
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for DecomposingNormalizer
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for DecomposingNormalizer
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for DecomposingNormalizer
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>